package com.hyp.web.controller.manager;

import cn.hutool.core.collection.CollUtil;
import cn.hutool.core.io.FileUtil;
import com.hyp.common.core.domain.AjaxResult;
import com.hyp.common.exception.ServiceException;
import com.hyp.system.domain.RewFileRelation;
import com.hyp.system.service.RewFileRelationService;
import org.springframework.stereotype.Component;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.List;
import java.util.Objects;

/**
 * packageName com.hyp.web.controller.manager
 *
 * @author wangxy
 * @version JDK 8
 * @className FileRelationManager
 * @date 2024/4/12
 * @description 文件
 */
@Component
public class FileRelationManager {

    @Resource
    private RewFileRelationService fileRelationService;

    /**
     *
     *  删除文件
     * @return boolean
     */
    public  boolean delFile(String fileId){
         RewFileRelation fileRelation = fileRelationService.getById(fileId);
         if(Objects.isNull(fileRelation)){
             throw new ServiceException("文件不存在");
         }
        FileUtil.del(fileRelation.getFilePath());
        return  fileRelationService.removeById(fileId);

    }
    /**
     *
     *  材料审核
     * @param applyId
     * @param fileCode
     * @param fileState
     * @return boolean
     */
    public  boolean filePass( String applyId, String fileCode, Integer fileState){
        return fileRelationService.lambdaUpdate()
                .eq(RewFileRelation::getApplyId,applyId)
                .eq(RewFileRelation::getFileCode,fileCode)
                .set(RewFileRelation::getFileState,fileState)
                .update();


    }

    /**
     *
     *  验证文件是否审查
     * @param applyId
     * @return com.hyp.common.core.domain.AjaxResult
     */

    public AjaxResult checkFile(String applyId){
         List<RewFileRelation> list = fileRelationService.lambdaQuery()
                 .eq(RewFileRelation::getApplyId, applyId)
                 .list();
         if(CollUtil.isNotEmpty(list)){
             for(RewFileRelation rewFileRelation : list){
                 if(Objects.equals(rewFileRelation.getFileState(),2)){
                     return AjaxResult.error("材料存在未通过情况，请检查");
                 }
             }
         }
        return AjaxResult.success();
    }

    @Transactional(rollbackFor = Exception.class)
    public RewFileRelation save(String applyId,String filename,String fileCode,String url,String originalFilename){
        RewFileRelation rewFileRelation = new RewFileRelation();
        rewFileRelation.setApplyId(applyId);
        rewFileRelation.setFileName(filename);
        rewFileRelation.setFileCode(fileCode);
        rewFileRelation.setFilePath(url);
        rewFileRelation.setRealName(originalFilename);
        fileRelationService.save(rewFileRelation);
        return rewFileRelation;
    }

    /**
     *
     *  获取文件路劲
     * @param fileId
     * @return java.lang.String
     */

    public String getFilePath(String fileId){
         RewFileRelation fileRelation = fileRelationService.getById(fileId);
         if(Objects.nonNull(fileRelation)){
             return  fileRelation.getFilePath();
         }
        return null;
    }

    /**
     *
     *  获取文件名
     * @param fileId
     * @return java.lang.String
     */

    public String getRealName(String fileId){
        RewFileRelation fileRelation = fileRelationService.getById(fileId);
        if(Objects.nonNull(fileRelation)){
            return  fileRelation.getRealName();
        }
        return null;
    }




}
