package com.hyp.web.controller.manager;

import cn.hutool.core.convert.Convert;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.hyp.common.core.domain.model.LoginUser;
import com.hyp.common.utils.SecurityUtils;
import com.hyp.common.utils.StringUtils;
import com.hyp.system.domain.RewScoreInfo;
import com.hyp.system.domain.dto.ScoreInfoSaveDTO;
import com.hyp.system.service.RewScoreInfoService;
import org.springframework.stereotype.Component;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.Date;
import java.util.List;
import java.util.Objects;

/**
 * packageName com.hyp.web.controller.manager
 *
 * @author wangxy
 * @version JDK 8
 * @className ScoreInfoManager
 * @date 2024/4/12
 * @description 评分
 */
@Component
public class ScoreInfoManager {


    @Resource
    private RewScoreInfoService scoreInfoService;

    /**
     *
     *  保存
     * @param scoreInfo
     * @return boolean
     */
    @Transactional(rollbackFor = Exception.class)
    public  boolean saveOrUpdate(ScoreInfoSaveDTO scoreInfo){
        LoginUser loginUser = SecurityUtils.getLoginUser();
        RewScoreInfo rewScoreInfo = Convert.convert(RewScoreInfo.class, scoreInfo);
        rewScoreInfo.setCreateId(loginUser.getUserId());
        if(StringUtils.isNotEmpty(scoreInfo.getScoreId())){
            rewScoreInfo.setUpdateTime(new Date());
            rewScoreInfo.setUpdateBy(loginUser.getUsername());
        }else{
            rewScoreInfo.setCreateTime(new Date());
            rewScoreInfo.setCreateBy(loginUser.getUsername());
        }
        return scoreInfoService.saveOrUpdate(rewScoreInfo);
    }


    /**
     *
     *  查询评分
     * @param applyId
     * @param createId
     * @return java.util.List<com.hyp.system.domain.RewScoreInfo>
     */

    public List<RewScoreInfo> getScoreInfo(String applyId,Long createId){
        LambdaQueryWrapper<RewScoreInfo> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.eq(RewScoreInfo::getApplyId,applyId);
        queryWrapper.eq(Objects.nonNull(createId), RewScoreInfo::getCreateId, createId);
        return scoreInfoService.list(queryWrapper);

    }


}
