package com.hyp.web.controller.reward;

import com.hyp.common.annotation.Log;
import com.hyp.common.core.controller.BaseController;
import com.hyp.common.core.domain.AjaxResult;
import com.hyp.common.core.page.TableDataInfo;
import com.hyp.common.enums.BusinessType;
import com.hyp.system.domain.dto.ApplyInfoListDTO;
import com.hyp.system.domain.dto.ApplyInfoListSaveDTO;
import com.hyp.system.domain.vo.ApplyInfoListVO;
import com.hyp.web.controller.manager.ApplyInfoListManager;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.List;

/**
 * packageName com.hyp.web.controller.apply
 *
 * @author wangxy
 * @version JDK 8
 * @className TestController
 * @date 2024/4/10
 * @description 优秀学校奖申请
 */
@Api("优秀学校奖申请")
@RestController
@RequestMapping("/reward/apply")
public class ApplyController extends BaseController {


    @Resource
    private ApplyInfoListManager applyInfoListManager;

    @ApiOperation("查询")
    @PreAuthorize("@ss.hasPermi('reward:apply:list')")
    @GetMapping("/list")
    public TableDataInfo list(ApplyInfoListDTO applyInfoListDTO) {
        startPage();
        List<ApplyInfoListVO> list = applyInfoListManager.selectApplyInfoList(applyInfoListDTO);
        return getDataTable(list);
    }

    @ApiOperation("根据奖项类型生成applyId")
    @PreAuthorize("@ss.hasPermi('reward:apply:add')")
    @Log(title = "申请保存", businessType = BusinessType.INSERT)
    @GetMapping(value = "/getApplyId")
    public AjaxResult getApplyId(@RequestParam String applyType) {
        return success(applyInfoListManager.getApplyId(applyType));
    }

    @ApiOperation("提交申请")
    @Log(title = "提交申请", businessType = BusinessType.UPDATE)
    @PostMapping("/submit")
    public AjaxResult submit(@Validated @RequestBody ApplyInfoListSaveDTO applyInfoSaveDTO) {
        return toAjax(applyInfoListManager.submit(applyInfoSaveDTO));
    }

    @ApiOperation("删除申请")
    @Log(title = "删除申请", businessType = BusinessType.DELETE)
    @DeleteMapping("/delete/{applyId}")
    public AjaxResult delete(@PathVariable String applyId) {
        return toAjax(applyInfoListManager.deleteById(applyId));
    }

    @ApiOperation("申请详细")
    @GetMapping(value = "/detail/{applyId}")
    public AjaxResult detail(@PathVariable String applyId) {
        return success(applyInfoListManager.detail(applyId));
    }

    @ApiOperation("审核提交")
    @GetMapping(value = "/audit/{applyId}")
    public AjaxResult audit(@PathVariable String applyId) {
        return success(applyInfoListManager.audit(applyId));
    }

    @ApiOperation("申请退回")
    @GetMapping(value = "/applyBack")
    public AjaxResult applyBack(@RequestParam String applyId,
                                @RequestParam(required = false) String applyMsg) {
        return success(applyInfoListManager.applyBack(applyId,applyMsg));
    }






}
