package com.hyp.web.controller.reward;

import com.hyp.common.annotation.Log;
import com.hyp.common.config.HypConfig;
import com.hyp.common.core.controller.BaseController;
import com.hyp.common.core.domain.AjaxResult;
import com.hyp.common.enums.BusinessType;
import com.hyp.common.utils.file.FileUploadUtils;
import com.hyp.common.utils.file.FileUtils;
import com.hyp.framework.config.ServerConfig;
import com.hyp.web.controller.manager.FileRelationManager;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import java.io.File;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.nio.file.Files;


/**
 * packageName com.hyp.web.controller.reward
 *
 * @author wangxy
 * @version JDK 8
 * @className FileRelationController
 * @date 2024/4/12
 * @description 文件
 */
@Api("文件")
@RestController
@RequestMapping("/reward/file")
@Slf4j
public class FileRelationController extends BaseController {


    @Resource
    private FileRelationManager fileRelationManager;

    @Autowired
    private ServerConfig serverConfig;

    @ApiOperation("文件上传")
    @PostMapping("/upload")
    public AjaxResult uploadFile(MultipartFile file,
                                 @RequestParam String applyId,
                                 @RequestParam String filename,
                                 @RequestParam String fileCode) {
        try {
            // 上传文件路径
            String filePath = HypConfig.getUploadPath();
            // 上传并返回新文件名称
            String fileNames = FileUploadUtils.upload(filePath, file);
            String url = serverConfig.getUrl() + fileNames;
            String originalFilename = FileUtils.getNameNotSuffix(file.getOriginalFilename()) ;
            return  AjaxResult.success(fileRelationManager.save(applyId,filename,fileCode,url,originalFilename));
        } catch (Exception e) {
            return AjaxResult.error(e.getMessage());
        }
    }

    @ApiOperation("材料预览")
    @GetMapping("fileView/{fileId}")
    public void fileView(@PathVariable String fileId, HttpServletResponse response) throws IOException {
        String filePath = fileRelationManager.getFilePath(fileId);
        String fileName = fileRelationManager.getRealName(fileId);
        String encodedFileName = new String(fileName.getBytes("UTF-8"),"ISO-8859-1");
        InputStream in = null;
        OutputStream out = null;
        try {
            response.setHeader("content-disposition", "attachment;filename=" + encodedFileName + ".pdf");
            // 设置文件ContentType类型，这样设置，会自动判断下载文件类型
            response.setContentType("application/octet-stream;charset=utf-8");
            File file = new File(filePath);
            in = Files.newInputStream(file.toPath());
            // 从response对象获取输出流
            out = response.getOutputStream();
            // 将输入流中的数据读取出来，写到输出流中
            for (int b = -1; (b = in.read()) != -1; ) {
                out.write(b);
            }
        } catch (Exception e) {
            log.error("获取文件流失败：", e.getMessage(), e);
        } finally {
            if (in != null) {
                try {
                    in.close();
                } catch (IOException e) {
                    log.error(e.getMessage(), e);
                } finally {
                    if (out != null) {
                        out.close();
                    }
                }
            }
        }
    }

    @ApiOperation("材料删除")
    @Log(title = "材料删除", businessType = BusinessType.DELETE)
    @GetMapping("/delFile/{fileId}")
    public AjaxResult delFile(@PathVariable String fileId){
        return  toAjax(fileRelationManager.delFile(fileId));
    }


    @ApiOperation("材料审核")
    @GetMapping("/filePass")
    public AjaxResult filePass(@RequestParam String applyId,
                               @RequestParam String fileCode,
                               @RequestParam Integer fileState){
        return  toAjax(fileRelationManager.filePass(applyId,fileCode,fileState));
    }


    @ApiOperation("材料校验")
    @GetMapping("/checkFile/{applyId}")
    public AjaxResult checkFile(@PathVariable String applyId){
        return  fileRelationManager.checkFile(applyId);
    }





}
